diff options
| author | Nicolas Seinlet <nse@odoo.com> | 2015-10-19 11:43:44 +0200 |
|---|---|---|
| committer | Denis Ledoux <dle@odoo.com> | 2015-10-22 16:04:19 +0200 |
| commit | 8c4877ff0d8793927a5c7b146dad1d48eccfde4a (patch) | |
| tree | 60e4a8c83b2ad4012e22fbd69c53d6c6bf04e847 /addons/analytic_user_function/analytic_user_function.py | |
| parent | 5c9897a83f79834b5c54a79b944262556e3f87ee (diff) | |
[FIX] account_asset: Assets Analysis performance
In a real environment with a big dataset,
the query reponse time decreased from 750s to 6s,
by using a join on the sub-select instead of redoing
the select for each line.
Fixes #8812
Closes #9128
Diffstat (limited to 'addons/analytic_user_function/analytic_user_function.py')
0 files changed, 0 insertions, 0 deletions
